"""LLM-based frame selection package.

This package provides modules for using large language models to select
the best frame from top candidates.
"""

from sceneflow.selection.llm_selector import LLMFrameSelector

__all__ = [
    'LLMFrameSelector',
]
